==> skrooge-0.2.6.tar.gz: skrooge-0.2.6/skgbasegui/skggraphicsscene.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGGRAPHICSSCENE_H
#define SKGGRAPHICSSCENE_H
/** @file
 * This file is part of Skrooge and defines classes skgbjectmodelbase.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include <kglobal.h>

#include <QGraphicsScene>

/**
 * The skrooge graphic scene
 */
class KDE_EXPORT SKGGraphicsScene : public QGraphicsScene
{
        Q_OBJECT

public:

        /**
         * Default constructor
         * @param iParent the parent
         */
        SKGGraphicsScene(QObject * iParent = 0 );

        /**
         * Destructor
         */
        virtual ~SKGGraphicsScene();

signals:
        /**
         * This signal is launched when a double click is done
         */
        void doubleClicked();

protected:
        /**
         * This event handler, for event mouseEvent, can be reimplemented in a subclass to receive mouse doubleclick events for the scene.
         * @param mouseEvent the event
         */
        virtual void mouseDoubleClickEvent ( QGraphicsSceneMouseEvent * mouseEvent );

private:
        Q_DISABLE_COPY(SKGGraphicsScene);
};

#endif

==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skgbasegui/skggraphicsscene.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGGRAPHICSSCENE_H
#define SKGGRAPHICSSCENE_H
/** @file
 * This file is part of Skrooge and defines classes skgbjectmodelbase.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include <kglobal.h>

#include <QGraphicsScene>
#include "skgbasegui_export.h"
/**
 * The skrooge graphic scene
 */
class SKGBASEGUI_EXPORT SKGGraphicsScene : public QGraphicsScene
{
        Q_OBJECT

public:

        /**
         * Default constructor
         * @param iParent the parent
         */
        SKGGraphicsScene(QObject * iParent = 0 );

        /**
         * Destructor
         */
        virtual ~SKGGraphicsScene();

signals:
        /**
         * This signal is launched when a double click is done
         */
        void doubleClicked();

protected:
        /**
         * This event handler, for event mouseEvent, can be reimplemented in a subclass to receive mouse doubleclick events for the scene.
         * @param mouseEvent the event
         */
        virtual void mouseDoubleClickEvent ( QGraphicsSceneMouseEvent * mouseEvent );

private:
        Q_DISABLE_COPY(SKGGraphicsScene);
};

#endif
